@@ -15,9 +15,10 @@ class SyncHTTPClient(BaseHTTPClient):
     def close(self):
         self.__session.close()
 
-    def request(self, url: str, json: list = []):
+    def request(self, service: str, func: str, parameters: list = []):
+        url = self.BASE + service + "/" + func
         with self.__session.post(
-            url, json=json, headers=self.headers
+            url, json=parameters, headers=self.headers
         ) as response:
             data = response.json()
             try:
